min_notifiers library
Defines the notifier classes and base state management logic for the package.
Classes
- MinNotifier
- A robust, lightweight base class for reactive state management that extends ChangeNotifier.
Defines the notifier classes and base state management logic for the package.