min_props library

Defines property-based state management tools and configurations.

Classes

MinProps
An abstract base class that provides structural equality and hashing based on a provided set of properties.