min_providers library
Provides the core Provider components used to inject state into the widget tree.
Classes
- MinMultiProvider
- A multi-provider widget that manages the lifecycle (initialization, readiness, and disposal) of a collection of state management instances simultaneously.
-
MinProvider<
T extends ChangeNotifier> -
A standalone provider widget that manages the lifecycle (
onInit,onReady, anddispose) of a state manager instance.