onRequestAppExit method

Future<AppExitResponse> onRequestAppExit()

Called when the platform requests to terminate the application.

Returns an AppExitResponse indicating whether the application should proceed to exit or cancel the request.

Implementation

Future<AppExitResponse> onRequestAppExit() async {
  return AppExitResponse.exit;
}