min_extensions library
Provides extensions for BuildContext to simplify state access and management.
Extensions
- ProviderExtension on BuildContext
- Context extensions to easily retrieve state managers from the widget tree.
- TaggedNotifierExtension on T
- Allows for a fluent API to assign a tag to a Notifier registration.