min_widgets library
Provides the core widgets required for reacting to state changes and rebuilding the UI.
Classes
-
$<
T extends Listenable, K> - A highly optimized reactive widget that listens to a Listenable (such as MinNotifier, ChangeNotifier, or ValueNotifier) and rebuilds its builder only when the specific slice of state returned by the selector changes.