MinProps class abstract
An abstract base class that provides structural equality and hashing based on a provided set of properties.
Implementations of MinProps must provide a props record, which is then used to implement operator == and hashCode. This ensures that two instances of the same type are considered equal if their property values are identical.
Properties
- hashCode → int
-
Returns a hash code for this object based on its runtimeType and props.
no setteroverride
- props → Record
-
The collection of properties that define the equality of this instance.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
Compares this object with
otherfor structural equality.override